@@ -19,6 +19,7 @@ Usage::
         DescribeDBSubnetGroupsPaginator,
         DescribeEventSubscriptionsPaginator,
         DescribeEventsPaginator,
+        DescribeGlobalClustersPaginator,
         DescribeOrderableDBInstanceOptionsPaginator,
         DescribePendingMaintenanceActionsPaginator,
         DocDBClient,
@@ -42,6 +43,7 @@ Usage::
     describe_db_subnet_groups_paginator: DescribeDBSubnetGroupsPaginator = client.get_paginator("describe_db_subnet_groups")
     describe_event_subscriptions_paginator: DescribeEventSubscriptionsPaginator = client.get_paginator("describe_event_subscriptions")
     describe_events_paginator: DescribeEventsPaginator = client.get_paginator("describe_events")
+    describe_global_clusters_paginator: DescribeGlobalClustersPaginator = client.get_paginator("describe_global_clusters")
     describe_orderable_db_instance_options_paginator: DescribeOrderableDBInstanceOptionsPaginator = client.get_paginator("describe_orderable_db_instance_options")
     describe_pending_maintenance_actions_paginator: DescribePendingMaintenanceActionsPaginator = client.get_paginator("describe_pending_maintenance_actions")
     ```
@@ -58,6 +60,7 @@ from .paginator import (
     DescribeDBSubnetGroupsPaginator,
     DescribeEventsPaginator,
     DescribeEventSubscriptionsPaginator,
+    DescribeGlobalClustersPaginator,
     DescribeOrderableDBInstanceOptionsPaginator,
     DescribePendingMaintenanceActionsPaginator,
 )
@@ -80,6 +83,7 @@ __all__ = (
     "DescribeDBSubnetGroupsPaginator",
     "DescribeEventSubscriptionsPaginator",
     "DescribeEventsPaginator",
+    "DescribeGlobalClustersPaginator",
     "DescribeOrderableDBInstanceOptionsPaginator",
     "DescribePendingMaintenanceActionsPaginator",
     "DocDBClient",
